@@ -379,12 +379,12 @@ static void mergeContigs(const Graph& g,
 		unsigned overlap, Sequence& seq,
 		const Sequence& s, const ContigNode& node, const Path& path)
 {
-	assert(s.length() > overlap);
+	assert(s.length() >= overlap);
 	Sequence ao;
 	Sequence bo(s, 0, overlap);
 	Sequence o;
 	do {
-		assert(seq.length() > overlap);
+		assert(seq.length() >= overlap);
 		ao = seq.substr(seq.length() - overlap);
 		o = createConsensus(ao, bo);
 	} while (o.empty() && chomp(seq, 'n'));
@@ -991,6 +991,7 @@ int main(int argc, char** argv)
 		for (NewVertices::const_iterator it = g_newVertices.begin();
 				it != g_newVertices.end(); ++it) {
 			Graph::vertex_descriptor u = add_vertex(it->vpu, g);
+			(void)u;
 			assert(u == it->u);
 			add_edge(it->t, it->u, it->eptu, g);
 			add_edge(it->u, it->v, it->epuv, g);
