@@ -45,13 +45,15 @@ static const char USAGE_MESSAGE[] =
     "  -h, --hist=PREFIX           write the algorithm histograms with the given prefix. Histograms are omitted if no prefix is given.\n"
     "  -t, --threshold=N           set path support threshold to N. [4]\n"
     "  -x, --extract=N             extract N r-mers per read. [4]\n"
-    "  -m, --min-tests=N           set minimum number of sliding window moves to N. Cannot be higher than 127. [20]\n"
-    "  -M, --max-tests=N           set maximum number of sliding window moves to N. Cannot be higher than 127. [36]\n"
+    "  -m, --min-tests=N           set minimum number of sliding window moves to N. Cannot be higher than 127. [18]\n"
+    "  -M, --max-tests=N           set maximum number of sliding window moves to N. Cannot be higher than 127. [40]\n"
     "  -n, --branching=N           set maximum number of branching paths to N. [75]\n"
-		"  -r, --rmer=N                explicitly set r value (k value used by rresolver). The number of set r values should be equal to the number of read sizes.\n"
-		"  -a, --approx-factor         explicitly set coverage approximation factor.\n"
-		"  -q, --quality--threshold=N  minimum quality all bases in rmers should have, on average. [35] (UNUSED)\n"
+    "  -r, --rmer=N                explicitly set r value (k value used by rresolver). The number of set r values should be equal to the number of read sizes.\n"
+    "  -a, --approx-factor         explicitly set coverage approximation factor.\n"
+    "  -q, --quality--threshold=N  minimum quality all bases in rmers should have, on average. [35] (UNUSED)\n"
     "  -e, --error-correction      enable correction of a 1bp error in kmers. [false]\n"
+    "  -R, --max-read-size         upper limit on read size to consider for use with RResolver. [350]\n"
+    "  -f, --bf-mem-factor         factor to multiply Bloom filter memory budget with in order to stay within similar memory usage as the rest of the pipeline. [1.0]\n"
     "  -S, --supported=FILE        write supported paths to FILE.\n"
     "  -U, --unsupported=FILE      write unsupported paths to FILE.\n"
     "                              Used for path sequence quality check.\n"
@@ -93,10 +95,10 @@ int threshold = 4;
 int extract = 4;
 
 /** Minimum number of sliding window moves */
-int minTests = 20;
+int minTests = 18;
 
 /** Maximum number of sliding window moves */
-int maxTests = 36;
+int maxTests = 40;
 
 /** Maximum number of branching paths */
 int branching = 75;
@@ -113,6 +115,12 @@ int readQualityThreshold = 35;
 /** Flag indicating whether error correction is enabled */
 int errorCorrection = 0;
 
+/** Upper limit on read size to consider for use with RResolver. */
+unsigned maxReadSize = 350;
+
+/** factor to multiply Bloom filter memory budget with in order to stay within similar memory usage as the rest of the pipeline. */
+double bfMemFactor = 1.0;
+
 /** Name of the file to write supported paths to */
 std::string outputSupportedPathsPath;
 
@@ -125,7 +133,7 @@ int format; // used by ContigProperties
 
 }
 
-static const char shortopts[] = "b:j:g:c:k:h:t:x:m:M:n:r:a:q:eS:U:v";
+static const char shortopts[] = "b:j:g:c:k:h:t:x:m:M:n:r:a:q:eR:f:S:U:v";
 
 enum
 {
@@ -149,6 +157,8 @@ static const struct option longopts[] = {
 	{ "approx-factor", required_argument, NULL, 'a' },
 	{ "quality-threshold", required_argument, NULL, 'q' },
 	{ "error-correction", no_argument, &opt::errorCorrection, 1 },
+	{ "max-read-size", required_argument, NULL, 'R' },
+	{ "bf-mem-factor", required_argument, NULL, 'f' },
 	{ "supported", required_argument, NULL, 'S' },
 	{ "unsupported", required_argument, NULL, 'U' },
 	{ "adj", no_argument, &opt::format, ADJ },
@@ -318,6 +328,12 @@ main(int argc, char** argv)
 			arg >> r;
 			opt::rValues.push_back(r);
 			break;
+		case 'R':
+		  arg >> opt::maxReadSize;
+			break;
+		case 'f':
+		  arg >> opt::bfMemFactor;
+			break;
 		case 'a':
 			double a;
 			arg >> a;
